Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(206)

Unified Diff: components/exo/keyboard.h

Issue 2905383003: (fix landed) Reland of name MaximizeMode to TabletMode (Closed)
Patch Set: Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/views/tabs/tab_drag_controller.cc ('k') | components/exo/keyboard.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/exo/keyboard.h
diff --git a/components/exo/keyboard.h b/components/exo/keyboard.h
index 98c4a4a9692bb3861fb868ccb530541be320b1c1..1232d5c8e31ecfbb628bf195da5e63f9cc32b01b 100644
--- a/components/exo/keyboard.h
+++ b/components/exo/keyboard.h
@@ -27,7 +27,7 @@
class Keyboard : public ui::EventHandler,
public WMHelper::FocusObserver,
public WMHelper::InputDeviceEventObserver,
- public WMHelper::MaximizeModeObserver,
+ public WMHelper::TabletModeObserver,
public SurfaceObserver {
public:
explicit Keyboard(KeyboardDelegate* delegate);
@@ -50,10 +50,10 @@
// Overridden from ui::InputDeviceEventObserver:
void OnKeyboardDeviceConfigurationChanged() override;
- // Overridden from WMHelper::MaximizeModeObserver:
- void OnMaximizeModeStarted() override;
- void OnMaximizeModeEnding() override;
- void OnMaximizeModeEnded() override;
+ // Overridden from WMHelper::TabletModeObserver:
+ void OnTabletModeStarted() override;
+ void OnTabletModeEnding() override;
+ void OnTabletModeEnded() override;
private:
// Returns the effective focus for |window|.
« no previous file with comments | « chrome/browser/ui/views/tabs/tab_drag_controller.cc ('k') | components/exo/keyboard.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698